@@ -186,7 +186,15 @@ impl<'a, 'b, P: swc_ecma_visit::Fold> PassBuilder<'a, 'b, P> {
                     should_enable(self.target, EsVersion::Es2021)
                 ),
                 Optional::new(
-                    compat::es2020::es2020(),
+                    compat::es2020::es2020(compat::es2020::Config {
+                        nullish_coalescing: compat::es2020::nullish_coalescing::Config {
+                            no_document_all: self.loose
+                        },
+                        optional_chaining: compat::es2020::opt_chaining::Config {
+                            no_document_all: self.loose,
+                            pure_getter: self.loose
+                        }
+                    }),
                     should_enable(self.target, EsVersion::Es2020)
                 ),
                 Optional::new(
@@ -194,7 +202,12 @@ impl<'a, 'b, P: swc_ecma_visit::Fold> PassBuilder<'a, 'b, P> {
                     should_enable(self.target, EsVersion::Es2019)
                 ),
                 Optional::new(
-                    compat::es2018(),
+                    compat::es2018(compat::es2018::Config {
+                        object_rest_spread: compat::es2018::object_rest_spread::Config {
+                            no_symbol: self.loose,
+                            set_property: self.loose
+                        }
+                    }),
                     should_enable(self.target, EsVersion::Es2018)
                 ),
                 Optional::new(
@@ -210,6 +223,9 @@ impl<'a, 'b, P: swc_ecma_visit::Fold> PassBuilder<'a, 'b, P> {
                         self.top_level_mark,
                         comments.clone(),
                         compat::es2015::Config {
+                            computed_props: compat::es2015::computed_props::Config {
+                                loose: self.loose
+                            },
                             for_of: compat::es2015::for_of::Config {
                                 assume_array: self.loose
                             },
@@ -218,6 +234,10 @@ impl<'a, 'b, P: swc_ecma_visit::Fold> PassBuilder<'a, 'b, P> {
                                 loose: self.loose
                             },
                             regenerator: self.regenerator,
+                            template_literal: compat::es2015::template_literal::Config {
+                                ignore_to_primitive: self.loose,
+                                mutable_template: self.loose
+                            }
                         }
                     ),
                     should_enable(self.target, EsVersion::Es2015)
